OC.L10N.register(
    "groupfolders",
    {
    "Unset" : "ביטול הגדרה",
    "Denied (Inherited permission)" : "חסום (הרשאה בירושה)",
    "Allowed (Inherited permission)" : "מורשה (הרשאה בירושה)",
    "Denied" : "חסום",
    "Allowed" : "מורשה",
    "Access denied" : "הגישה נדחתה",
    "Inherit permission" : "הורשת הרשאה",
    "Deny" : "לדחות",
    "Allow" : "לאפשר",
    "Group" : "קבוצה",
    "Read" : "קריאה",
    "Write" : "כתיבה",
    "Create" : "יצירה",
    "Delete" : "מחיקה",
    "Share" : "שיתוף",
    "You" : "אני",
    "Remove access rule" : "הסרת כלל גישה",
    "Add advanced permission rule" : "הוספת כלל הרשאות מתקדמות",
    "Select a user or group" : "נא לבחור משתמש או קבוצה",
    "Add group" : "הוספת קבוצה",
    "Default" : "ברירת מחדל",
    "Unlimited" : "ללא הגבלה",
    "Delete \"{folderName}\"?" : "למחוק את „{folderName}”?",
    "Folder name" : "שם התיקייה",
    "Quota" : "מיכסה",
    "Advanced Permissions" : "הרשאות מתקדמות",
    "Previous" : "הקודם",
    "User" : "משתמש",
    "Unknown" : "לא ידוע",
    "None" : "ללא",
    "{size} used" : "{size} בשימוש"
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
